@@ -1,10 +1,14 @@
 #! /bin/sh
 #
-# Generic build (driven by environment variables)
+# Generic build. The build is driven by environment variables:
+# - SRCDIR      (e.g. /src)
+# - BUILDDIR    (e.g. /build)
+# - CMAKE_ARGS  (e.g. "-DWITH_QT6=ON -DCMAKE_BUILD_TYPE=Debug")
 #
 
 # Sanity check
 test -n "$BUILDDIR" || { echo "! \$BUILDDIR not set" ; exit 1 ; }
+test -n "$SRCDIR" || { echo "! \$SRCDIR not set" ; exit 1 ; }
 mkdir -p "$BUILDDIR"
 test -f "$SRCDIR/CMakeLists.txt" || { echo "! Missing $SRCDIR/CMakeLists.txt" ; exit 1 ; }
 
