@@ -11,6 +11,7 @@
 # Run it with a -v command-line option to get extra output on
 # actual translation percentages.
 import sys
+import os
 import argparse
 
 class TXError(Exception):
@@ -31,12 +32,31 @@ class TransifexGetter(object):
             raise TXError("Could not get Transifex API token")
 
         import requests
-        r = requests.get("https://api.transifex.com/organizations/calamares/projects/calamares/resources/calamares/", auth=("api", token))
+        base_url = "https://rest.api.transifex.com/resource_language_stats"
+        project_filter = "filter[project]=o:calamares:p:calamares"
+        resource_filter = "filter[resource]=o:calamares:p:calamares:r:calamares"
+        url = base_url + "?" + project_filter.replace(":", "%3A") + "&" + resource_filter.replace(":", "%3A")
+        headers = {
+            "accept": "application/vnd.api+json",
+            "authorization": "Bearer " + token
+        }
+
+        r = requests.get(url, headers=headers)
         if r.status_code != 200:
             raise TXError("Could not get Transifex data from API")
 
         j = r.json()
-        self.languages = j["stats"]
+        data = j["data"]
+
+        self.languages = dict()
+
+        for d in data:
+            translated_count = d["attributes"]["translated_strings"]
+            total_count = d["attributes"]["total_strings"]
+            language_key = d["relationships"]["language"]["data"]["id"]
+            assert language_key.startswith("l:")
+            language_key = language_key[2:]
+            self.languages[language_key] = dict(translated=dict(stringcount=translated_count, percentage=(translated_count / total_count)))
 
 
     def get_tx_credentials(self):
@@ -52,7 +72,7 @@ class TransifexGetter(object):
                 parser = configparser.ConfigParser()
                 parser.read_file(f)
 
-                return parser.get("https://www.transifex.com", "password")
+                return parser.get("https://app.transifex.com", "password")
         except IOError as e:
             return None
 
@@ -96,10 +116,12 @@ class EditingOutputter(object):
             lines = f.readlines()
 
         mark = None
+        mark_text = None
         for l in lines:
             # Note that we didn't strip the lines, so need the \n here
             if l.startswith("# Total ") and l.endswith(" languages\n"):
                 mark = lines.index(l)
+                mark_text = l
                 break
         if mark is None:
             raise TXError("No CMakeLists.txt lines for TX stats found")
@@ -107,18 +129,17 @@ class EditingOutputter(object):
 
         nextmark = mark + 1
         for l in lines[mark+1:]:
-            if l.startswith("set( _tx_"):
-                nextmark += 1
-                continue
-            if l.startswith("    "):
-                nextmark += 1
-                continue
-            break
-        if nextmark > mark + 12 or nextmark > len(lines) - 4:
+            nextmark += 1
+            if l.startswith(mark_text):
+                break
+        if nextmark > mark + 100 or nextmark > len(lines) - 4:
             # Try to catch runaway nextmarks: we know there should
             # be four set-lines, which are unlikely to be 3 lines each;
             # similarly the CMakeLists.txt is supposed to end with
             # some boilerplate.
+            #
+            # However, gersemi will reformat to one-language-per-line,
+            # so we can get really long sections, that's why we use 100 as a limit.
             raise TXError("Could not find end of TX settings in CMakeLists.txt")
         self.post_lines = lines[nextmark:]
 
@@ -172,23 +193,19 @@ def get_tx_stats(languages, outputter, verbose):
 
     If @p verbose is True, prints out language stats as well.
     """
-    suppressed_languages = ( "es_ES", )  # In Transifex, but not used
     # Some languages go into the "incomplete" list by definition,
     # regardless of their completion status: this can have various reasons.
     #
-    # Note that Esperanto (eo) is special-cased in CMakeLists.txt
-    # during the build; recent Qt releases *do* support the language,
-    # and it's at-the-least ok.
+    # - (Esperanto wasn't supported until Qt 5.12.2)
+    # - Interlingue still is not supported by the minimum Qt version
     incomplete_languages = (
-        "eo",   # Not supported by QLocale < 5.12.1
         "ie",   # Not supported by Qt at least through 5.15.0
         )
 
     all_langs = []
-    outputter.print("# Total %d languages" % len(languages))
+    mark_text = "# Total %d languages" % len(languages)
+    outputter.print(mark_text)
     for lang_name in languages:
-        if lang_name in suppressed_languages:
-            continue
         stats = languages[lang_name]["translated"]["percentage"]
         # Make the by-definition-incomplete languages have a percentage
         # lower than zero; this way they end up sorted (in -v output)
@@ -204,6 +221,39 @@ def get_tx_stats(languages, outputter, verbose):
     output_langs(all_langs, outputter, "good", lambda s : 1.0 > s >= 0.75)
     output_langs(all_langs, outputter, "ok", lambda s : 0.75 > s >= 0.05)
     output_langs(all_langs, outputter, "incomplete", lambda s : 0.05 > s)
+    outputter.print(mark_text)
+
+    # Audit the languages that are in TX, mapped to git
+    for lang_name in languages:
+        if not os.path.exists("lang/calamares_{}.ts".format(lang_name)):
+            print("# !! Missing translation file for {}".format(lang_name))
+        if not os.path.isdir("lang/python/{}/LC_MESSAGES".format(lang_name)):
+            print("# !! Missing Python translation file for {}".format(lang_name))
+
+    # Audit the files that are in git, mapped to TX
+    special_cases = ("python.pot", "python", "CMakeLists.txt", "txload.cpp", "calamares_i18n.qrc.in")
+    for file_name in os.listdir("lang"):
+        if file_name in special_cases:
+            continue
+        elif file_name.startswith("calamares_") and file_name.endswith(".ts"):
+            key = file_name[10:-3]
+            if not key in languages and not key == "en":
+                print("# !! Translation file for {} not in TX".format(key))
+        elif file_name.startswith("tz_") and file_name.endswith(".ts"):
+            key = file_name[3:-3]
+            if not key in languages and not key == "en":
+                print("# !! Translation file for TZ {} not in TX".format(key))
+        elif file_name.startswith("kb_") and file_name.endswith(".ts"):
+            key = file_name[3:-3]
+            if not key in languages and not key == "en":
+                print("# !! Translation file for KB {} not in TX".format(key))
+        else:
+            print("# !! Weird translation file {} not in TX".format(file_name))
+
+    # Audit the python translation files that are in git, mapped to TX
+    for file_name in os.listdir("lang/python"):
+        if file_name not in languages:
+            print("# !! Translation file for Python {} not in TX".format(file_name))
 
     return 0
 
