@@ -89,6 +89,9 @@ public:
     /// @brief Explicif filename, debug is always true (for testing)
     static Settings* init( const QString& filename );
 
+    /// @brief Get the path this settings was created for (may be empty)
+    QString path() const { return m_settingsPath; }
+
     QStringList modulesSearchPaths() const;
 
     using InstanceDescriptionList = QList< InstanceDescription >;
@@ -152,8 +155,21 @@ public:
      */
     bool isSetupMode() const { return m_isSetupMode; }
 
+    /** @brief Returns whether the named module is enabled
+     *
+     *  Returns true if @p module is enabled in settings.conf.  Be aware that it
+     *  only tests for a specific module name so if a QML and non-QML version
+     *  of the same module exists, it must be specified explicitly
+     *
+     *  @p module is a module name or module key e.g. packagechooser) and not a
+     *  full module key+id (e.g. packagechooser@packagechooser)
+     *
+    */
+    bool isModuleEnabled( const QString& module ) const;
+
     /** @brief Global setting of disable-cancel: can't cancel ever. */
     bool disableCancel() const { return m_disableCancel; }
+
     /** @brief Temporary setting of disable-cancel: can't cancel during exec. */
     bool disableCancelDuringExec() const { return m_disableCancelDuringExec; }
 
@@ -164,6 +180,7 @@ public:
 
 private:
     static Settings* s_instance;
+    QString m_settingsPath;
 
     QStringList m_modulesSearchPaths;
 
