@@ -1,23 +1,11 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
- * 
+/* === This file is part of Calamares - <https://calamares.io> ===
+ *
  *   SPDX-FileCopyrightText: 2014-2015 Teo Mrnjavac <teo@kde.org>
  *   SPDX-FileCopyrightText: 2017 Adriaan de Groot <groot@kde.org>
- *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
- *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
- *
  *   SPDX-License-Identifier: GPL-3.0-or-later
- *   License-Filename: LICENSE
+ *
+ *   Calamares is Free Software: see the License-Identifier above.
+ *
  *
  */
 
@@ -53,30 +41,8 @@ Module* moduleFromDescriptor( const ModuleSystem::Descriptor& moduleDescriptor,
 class DLLEXPORT Module
 {
 public:
-    /**
-     * @brief The Type enum represents the intended functionality of the module
-     * Every module is either a job module or a view module.
-     * A job module is a single Calamares job.
-     * A view module has a UI (one or more view pages) and zero-to-many jobs.
-     */
-    enum class Type
-    {
-        Job,
-        View
-    };
-
-    /**
-     * @brief The Interface enum represents the interface through which the module
-     * talks to Calamares.
-     * Not all Type-Interface associations are valid.
-     */
-    enum class Interface
-    {
-        QtPlugin,  // Jobs or Views
-        Python,  // Jobs only
-        Process,  // Deprecated interface
-        PythonQt  // Views only, available as enum even if PythonQt isn't used
-    };
+    using Type = ModuleSystem::Type;
+    using Interface = ModuleSystem::Interface;
 
     virtual ~Module();
 
@@ -176,9 +142,9 @@ protected:
     explicit Module();
 
     /// @brief For subclasses to read their part of the descriptor
-    virtual void initFrom( const QVariantMap& moduleDescriptor ) = 0;
+    virtual void initFrom( const ModuleSystem::Descriptor& moduleDescriptor ) = 0;
     /// @brief Generic part of descriptor reading (and instance id)
-    void initFrom( const QVariantMap& moduleDescriptor, const QString& id );
+    void initFrom( const ModuleSystem::Descriptor& moduleDescriptor, const QString& id );
 
     QVariantMap m_configurationMap;
 
