@@ -14,7 +14,7 @@
 
 #include <QObject>
 
-namespace CalamaresUtils
+namespace Calamares
 {
 namespace Partition
 {
@@ -30,13 +30,13 @@ prettyNameForFileSystemType( FileSystem::Type t )
     switch ( t )
     {
     case FileSystem::Unknown:
-        return QObject::tr( "unknown" );
+        return QObject::tr( "unknown", "@partition info" );
     case FileSystem::Extended:
-        return QObject::tr( "extended" );
+        return QObject::tr( "extended", "@partition info" );
     case FileSystem::Unformatted:
-        return QObject::tr( "unformatted" );
+        return QObject::tr( "unformatted", "@partition info" );
     case FileSystem::LinuxSwap:
-        return QObject::tr( "swap" );
+        return QObject::tr( "swap", "@partition info" );
     case FileSystem::Fat16:
     case FileSystem::Fat32:
     case FileSystem::Ntfs:
@@ -46,6 +46,7 @@ prettyNameForFileSystemType( FileSystem::Type t )
     case FileSystem::Ufs:
     case FileSystem::Hpfs:
     case FileSystem::Luks:
+    case FileSystem::Luks2:
     case FileSystem::Ocfs2:
     case FileSystem::Zfs:
     case FileSystem::Nilfs2:
@@ -91,4 +92,4 @@ untranslatedFS( FileSystem::Type t )
 }
 
 }  // namespace Partition
-}  // namespace CalamaresUtils
+}  // namespace Calamares
