@@ -26,26 +26,19 @@
  * To avoid overly-many warnings related to the API change, introduce
  * Calamares-specific constants that pull from the correct enum.
  */
-constexpr static const auto SplitSkipEmptyParts =
-#if QT_VERSION < QT_VERSION_CHECK( 5, 14, 0 )
-    QString::SkipEmptyParts
-#else
-    Qt::SkipEmptyParts
-#endif
-    ;
+constexpr static const auto SplitSkipEmptyParts = Qt::SkipEmptyParts;
 
-constexpr static const auto SplitKeepEmptyParts =
-#if QT_VERSION < QT_VERSION_CHECK( 5, 14, 0 )
-    QString::KeepEmptyParts
-#else
-    Qt::KeepEmptyParts
-#endif
-    ;
+constexpr static const auto SplitKeepEmptyParts = Qt::KeepEmptyParts;
 
+namespace Calamares
+{
 /**
- * @brief The CalamaresUtils namespace contains utility functions.
+ * @brief The Calamares::String namespace
+ *
+ * This namespace contains functions related to string-handling,
+ * string-expansion, etc.
  */
-namespace CalamaresUtils
+namespace String
 {
 /**
  * @brief removeDiacritics replaces letters with diacritics and ligatures with
@@ -100,6 +93,20 @@ DLLEXPORT QString truncateMultiLine( const QString& string,
                                      LinesStartEnd lines = LinesStartEnd { 3, 5 },
                                      CharCount chars = CharCount { 812 } );
 
-}  // namespace CalamaresUtils
+/** @brief Remove all @p c at the beginning of @p string
+ *
+ * Modifies the @p string in-place. If @p c is not the first character
+ * of @p string, the string is left unchanged; otherwise the first character
+ * is removed and the process repeats.
+ */
+DLLEXPORT void removeLeading( QString& string, QChar c );
+/** @brief Remove all @p c at the end of @p string
+ *
+ * Like removeLeading(), but at the end of the string.
+ */
+DLLEXPORT void removeTrailing( QString& string, QChar c );
+
+}  // namespace String
+}  // namespace Calamares
 
 #endif
