@@ -1,23 +1,11 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
- * 
+/* === This file is part of Calamares - <https://calamares.io> ===
+ *
  *   SPDX-FileCopyrightText: 2019 Adriaan de Groot <groot@kde.org>
- *
- *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
- *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
- *
  *   SPDX-License-Identifier: GPL-3.0-or-later
- *   License-Filename: LICENSE
+ *
+ *
+ *   Calamares is Free Software: see the License-Identifier above.
+ *
  *
  */
 #ifndef UTILS_UMASK_H
@@ -27,7 +15,7 @@
 
 #include <sys/types.h>
 
-namespace CalamaresUtils
+namespace Calamares
 {
 /** @brief Wrapper for umask(2)
  *
@@ -57,6 +45,6 @@ public:
 private:
     mode_t m_mode;
 };
-}  // namespace CalamaresUtils
+}  // namespace Calamares
 
 #endif
