@@ -15,7 +15,12 @@
 
 #include <QtCore/QIntegerForSize>
 
-namespace CalamaresUtils
+namespace Calamares
+{
+/// @brief Type for expressing units
+using intunit_t = quint64;
+
+namespace Units
 {
 
 /** User defined literals, 1_KB is 1 KiloByte (= 10^3 bytes) */
@@ -54,40 +59,42 @@ constexpr qint64 operator""_GiB( unsigned long long m )
     return operator""_MiB(m)*1024;
 }
 
+}  // namespace Units
+
 constexpr qint64
 KBtoBytes( unsigned long long m )
 {
-    return operator""_KB( m );
+    return Units::operator""_KB( m );
 }
 
 constexpr qint64
 KiBtoBytes( unsigned long long m )
 {
-    return operator""_KiB( m );
+    return Units::operator""_KiB( m );
 }
 
 constexpr qint64
 MBtoBytes( unsigned long long m )
 {
-    return operator""_MB( m );
+    return Units::operator""_MB( m );
 }
 
 constexpr qint64
 MiBtoBytes( unsigned long long m )
 {
-    return operator""_MiB( m );
+    return Units::operator""_MiB( m );
 }
 
 constexpr qint64
 GBtoBytes( unsigned long long m )
 {
-    return operator""_GB( m );
+    return Units::operator""_GB( m );
 }
 
 constexpr qint64
 GiBtoBytes( unsigned long long m )
 {
-    return operator""_GiB( m );
+    return Units::operator""_GiB( m );
 }
 
 constexpr qint64
@@ -132,12 +139,19 @@ BytesToMiB( qint64 b )
     return int( b / 1024 / 1024 );
 }
 
+// TODO: deprecate signed version
 constexpr int
 BytesToGiB( qint64 b )
 {
     return int( b / 1024 / 1024 / 1024 );
 }
 
+constexpr intunit_t
+BytesToGiB( intunit_t b )
+{
+    return b / 1024 / 1024 / 1024;
+}
+
 constexpr qint64
 alignBytesToBlockSize( qint64 bytes, qint64 blocksize )
 {
@@ -156,5 +170,6 @@ bytesToSectors( qint64 bytes, qint64 blocksize )
     return alignBytesToBlockSize( alignBytesToBlockSize( bytes, blocksize ), MiBtoBytes( 1ULL ) ) / blocksize;
 }
 
-}  // namespace CalamaresUtils
+}  // namespace Calamares
+
 #endif
