@@ -10,20 +10,37 @@
 #ifndef UTILS_PASTE_H
 #define UTILS_PASTE_H
 
-#include <qglobal.h>  // for quint16
+#include "DllMacro.h"
+
+#include <QString>
 
 class QObject;
-class QString;
+class QWidget;
 
-namespace CalamaresUtils
+namespace Calamares
+{
+namespace Paste
 {
-
 /** @brief Send the current log file to a pastebin
  *
  * Returns the (string) URL that the pastebin gives us.
  */
-QString sendLogToPastebin( QObject* parent, const QString& ficheHost, quint16 fichePort );
+UIDLLEXPORT QString doLogUpload( QObject* parent );
 
-}  // namespace CalamaresUtils
+/** @brief Send the current log file to a pastebin
+ *
+ * As doLogUpload(), but also sets the clipboard and displays
+ * a message saying it's been done.
+ */
+UIDLLEXPORT QString doLogUploadUI( QWidget* parent );
+
+/** @brief Is paste enabled?
+ *
+ * Checks the branding instance if paste can be done.
+ */
+UIDLLEXPORT bool isEnabled();
+}  // namespace Paste
+
+}  // namespace Calamares
 
 #endif
