@@ -1,20 +1,11 @@
-/* === This file is part of Calamares - <https://github.com/calamares> ===
+/* === This file is part of Calamares - <https://calamares.io> ===
  *
- *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2017, 2020, Adriaan de Groot <groot@kde.org>
+ *   SPDX-FileCopyrightText: 2014-2015 Teo Mrnjavac <teo@kde.org>
+ *   SPDX-FileCopyrightText: 2017 Adriaan de Groot <groot@kde.org>
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  *
- *   Calamares is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
+ *   Calamares is Free Software: see the License-Identifier above.
  *
- *   Calamares is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef VIEWSTEP_H
@@ -38,8 +29,7 @@ namespace Calamares
  * A view module is a Calamares module which has at least one UI page (exposed as
  * ViewStep::widget), and can optionally create Calamares jobs at runtime.
  * As of early 2020, a view module can be implemented by deriving from ViewStep
- * in C++ (as a Qt Plugin or a Qml ViewStep) or in Python with the PythonQt interface
- * (which also mimics the ViewStep class).
+ * in C++ (as a Qt Plugin or a Qml ViewStep).
  *
  * A ViewStep can describe itself in human-readable format for the SummaryPage
  * (which shows all of the things which have been collected to be done in the
@@ -50,7 +40,7 @@ class UIDLLEXPORT ViewStep : public QObject
     Q_OBJECT
 public:
     explicit ViewStep( QObject* parent = nullptr );
-    virtual ~ViewStep() override;
+    ~ViewStep() override;
 
     /** @brief Human-readable name of the step
      *
