@@ -23,9 +23,16 @@
 #include "utils/Variant.h"
 
 #include <QApplication>
+#include <QFile>
+#include <QGuiApplication>
 #include <QProcess>
+#include <QRegularExpression>
 #include <QTimer>
 
+#include <QDBusConnection>
+#include <QDBusInterface>
+#include <QDBusReply>
+
 /* Returns stringlist with suitable setxkbmap command-line arguments
  * to set the given @p model.
  */
@@ -36,7 +43,6 @@ xkbmap_model_args( const QString& model )
     return r;
 }
 
-
 /* Returns stringlist with suitable setxkbmap command-line arguments
  * to set the given @p layout and @p variant.
  */
@@ -108,7 +114,7 @@ xkbmap_query_grp_option()
     }
 
     //it's either in the end of line or before the other option so \s or ,
-    int lastIndex = outputLine.indexOf( QRegExp( "[\\s,]" ), index );
+    int lastIndex = outputLine.indexOf( QRegularExpression( "[\\s,]" ), index );
 
     return outputLine.mid( index, lastIndex - index );
 }
@@ -153,6 +159,7 @@ Config::Config( QObject* parent )
     , m_keyboardModelsModel( new KeyboardModelsModel( this ) )
     , m_keyboardLayoutsModel( new KeyboardLayoutModel( this ) )
     , m_keyboardVariantsModel( new KeyboardVariantsModel( this ) )
+    , m_KeyboardGroupSwitcherModel( new KeyboardGroupsSwitchersModel( this ) )
 {
     m_setxkbmapTimer.setSingleShot( true );
 
@@ -163,7 +170,14 @@ Config::Config( QObject* parent )
              {
                  // Set Xorg keyboard model
                  m_selectedModel = m_keyboardModelsModel->key( index );
-                 QProcess::execute( "setxkbmap", xkbmap_model_args( m_selectedModel ) );
+                 if ( m_useLocale1 )
+                 {
+                     locale1Apply();
+                 }
+                 else
+                 {
+                     QProcess::execute( "setxkbmap", xkbmap_model_args( m_selectedModel ) );
+                 }
                  emit prettyStatusChanged();
              } );
 
@@ -176,37 +190,98 @@ Config::Config( QObject* parent )
                  emit prettyStatusChanged();
              } );
 
-    connect( m_keyboardVariantsModel, &KeyboardVariantsModel::currentIndexChanged, this, &Config::xkbChanged );
+    connect( m_keyboardVariantsModel,
+             &KeyboardVariantsModel::currentIndexChanged,
+             [ & ]( int index )
+             {
+                 m_selectedVariant = m_keyboardVariantsModel->key( index );
+                 xkbChanged();
+                 emit prettyStatusChanged();
+             } );
+    connect( m_KeyboardGroupSwitcherModel,
+             &KeyboardGroupsSwitchersModel::currentIndexChanged,
+             [ & ]( int index )
+             {
+                 m_selectedGroup = m_KeyboardGroupSwitcherModel->key( index );
+                 xkbChanged();
+                 emit prettyStatusChanged();
+             } );
 
     // If the user picks something explicitly -- not a consequence of
     // a guess -- then move to UserSelected state and stay there.
     connect( m_keyboardModelsModel, &KeyboardModelsModel::currentIndexChanged, this, &Config::selectionChange );
     connect( m_keyboardLayoutsModel, &KeyboardLayoutModel::currentIndexChanged, this, &Config::selectionChange );
     connect( m_keyboardVariantsModel, &KeyboardVariantsModel::currentIndexChanged, this, &Config::selectionChange );
+    connect( m_KeyboardGroupSwitcherModel,
+             &KeyboardGroupsSwitchersModel::currentIndexChanged,
+             this,
+             &Config::selectionChange );
 
     m_selectedModel = m_keyboardModelsModel->key( m_keyboardModelsModel->currentIndex() );
     m_selectedLayout = m_keyboardLayoutsModel->item( m_keyboardLayoutsModel->currentIndex() ).first;
     m_selectedVariant = m_keyboardVariantsModel->key( m_keyboardVariantsModel->currentIndex() );
+    m_selectedGroup = m_KeyboardGroupSwitcherModel->key( m_KeyboardGroupSwitcherModel->currentIndex() );
 }
 
 void
-Config::xkbChanged( int index )
+Config::xkbChanged()
 {
     // Set Xorg keyboard layout + variant
-    m_selectedVariant = m_keyboardVariantsModel->key( index );
-
     if ( m_setxkbmapTimer.isActive() )
     {
         m_setxkbmapTimer.stop();
         m_setxkbmapTimer.disconnect( this );
     }
 
-    connect( &m_setxkbmapTimer, &QTimer::timeout, this, &Config::xkbApply );
+    if ( m_useLocale1 )
+    {
+        connect( &m_setxkbmapTimer, &QTimer::timeout, this, &Config::locale1Apply );
+    }
+    else
+    {
+        connect( &m_setxkbmapTimer, &QTimer::timeout, this, &Config::xkbApply );
+    }
 
     m_setxkbmapTimer.start( QApplication::keyboardInputInterval() );
     emit prettyStatusChanged();
 }
 
+void
+Config::locale1Apply()
+{
+    m_additionalLayoutInfo = getAdditionalLayoutInfo( m_selectedLayout );
+
+    QString layout = m_selectedLayout;
+    QString variant = m_selectedVariant;
+    QString option;
+
+    if ( !m_additionalLayoutInfo.additionalLayout.isEmpty() )
+    {
+        layout = m_additionalLayoutInfo.additionalLayout + "," + layout;
+        variant = m_additionalLayoutInfo.additionalVariant + "," + variant;
+        option = m_additionalLayoutInfo.groupSwitcher;
+    }
+
+    QDBusInterface locale1( "org.freedesktop.locale1",
+                            "/org/freedesktop/locale1",
+                            "org.freedesktop.locale1",
+                            QDBusConnection::systemBus() );
+    if ( !locale1.isValid() )
+    {
+        cWarning() << "Interface" << locale1.interface() << "is not valid.";
+        return;
+    }
+
+    // Using convert=true, this also updates the VConsole config
+    {
+        QDBusReply< void > r = locale1.call( "SetX11Keyboard", layout, m_selectedModel, variant, option, true, false );
+        if ( !r.isValid() )
+        {
+            cWarning() << "Could not set keyboard config through org.freedesktop.locale1.X11Keyboard." << r.error();
+        }
+    }
+}
+
 void
 Config::xkbApply()
 {
@@ -214,8 +289,15 @@ Config::xkbApply()
 
     if ( !m_additionalLayoutInfo.additionalLayout.isEmpty() )
     {
-        m_additionalLayoutInfo.groupSwitcher = xkbmap_query_grp_option();
+        if ( !m_selectedGroup.isEmpty() )
+        {
+            m_additionalLayoutInfo.groupSwitcher = "grp:" + m_selectedGroup;
+        }
 
+        if ( m_additionalLayoutInfo.groupSwitcher.isEmpty() )
+        {
+            m_additionalLayoutInfo.groupSwitcher = xkbmap_query_grp_option();
+        }
         if ( m_additionalLayoutInfo.groupSwitcher.isEmpty() )
         {
             m_additionalLayoutInfo.groupSwitcher = "grp:alt_shift_toggle";
@@ -226,7 +308,6 @@ Config::xkbApply()
                                                { m_additionalLayoutInfo.additionalVariant, m_selectedVariant },
                                                m_additionalLayoutInfo.groupSwitcher ) );
 
-
         cDebug() << "xkbmap selection changed to: " << m_selectedLayout << '-' << m_selectedVariant << "(added "
                  << m_additionalLayoutInfo.additionalLayout << "-" << m_additionalLayoutInfo.additionalVariant
                  << " since current layout is not ASCII-capable)";
@@ -239,7 +320,6 @@ Config::xkbApply()
     m_setxkbmapTimer.disconnect( this );
 }
 
-
 KeyboardModelsModel*
 Config::keyboardModels() const
 {
@@ -258,6 +338,12 @@ Config::keyboardVariants() const
     return m_keyboardVariantsModel;
 }
 
+KeyboardGroupsSwitchersModel*
+Config::keyboardGroupsSwitchers() const
+{
+    return m_KeyboardGroupSwitcherModel;
+}
+
 static QPersistentModelIndex
 findLayout( const KeyboardLayoutModel* klm, const QString& currentLayout )
 {
@@ -276,21 +362,10 @@ findLayout( const KeyboardLayoutModel* klm, const QString& currentLayout )
 }
 
 void
-Config::detectCurrentKeyboardLayout()
+Config::getCurrentKeyboardLayoutXkb( QString& currentLayout, QString& currentVariant, QString& currentModel )
 {
-    if ( m_state != State::Initial )
-    {
-        return;
-    }
-    cScopedAssignment returnToIntial( &m_state, State::Initial );
-    m_state = State::Guessing;
-
-    //### Detect current keyboard layout and variant
-    QString currentLayout;
-    QString currentVariant;
     QProcess process;
     process.start( "setxkbmap", QStringList() << "-print" );
-
     if ( process.waitForFinished() )
     {
         const QStringList list = QString( process.readAll() ).split( "\n", SplitSkipEmptyParts );
@@ -299,7 +374,12 @@ Config::detectCurrentKeyboardLayout()
         //      xkb_symbols   { include "pc+latin+ru:2+inet(evdev)+group(alt_shift_toggle)+ctrl(swapcaps)"       };
         for ( const auto& line : list )
         {
-            if ( !line.trimmed().startsWith( "xkb_symbols" ) )
+            bool symbols = false;
+            if ( line.trimmed().startsWith( "xkb_symbols" ) )
+            {
+                symbols = true;
+            }
+            else if ( !line.trimmed().startsWith( "xkb_geometry" ) )
             {
                 continue;
             }
@@ -314,7 +394,7 @@ Config::detectCurrentKeyboardLayout()
 
             QStringList split = line.mid( firstQuote + 1, lastQuote - firstQuote ).split( "+", SplitSkipEmptyParts );
             cDebug() << split;
-            if ( split.size() >= 2 )
+            if ( symbols && split.size() >= 2 )
             {
                 currentLayout = split.at( 1 );
 
@@ -328,8 +408,61 @@ Config::detectCurrentKeyboardLayout()
 
                 break;
             }
+            else if ( !symbols && split.size() >= 1 )
+            {
+                currentModel = split.at( 0 );
+                if ( currentModel.contains( "(" ) )
+                {
+                    int parenthesisIndex = currentLayout.indexOf( "(" );
+                    currentModel = currentModel.mid( parenthesisIndex + 1 ).trimmed();
+                    currentModel.chop( 1 );
+                }
+            }
         }
     }
+}
+
+void
+Config::getCurrentKeyboardLayoutLocale1( QString& currentLayout, QString& currentVariant, QString& currentModel )
+{
+    QDBusInterface locale1( "org.freedesktop.locale1",
+                            "/org/freedesktop/locale1",
+                            "org.freedesktop.locale1",
+                            QDBusConnection::systemBus() );
+    if ( !locale1.isValid() )
+    {
+        cWarning() << "Interface" << locale1.interface() << "is not valid.";
+        return;
+    }
+
+    currentLayout = locale1.property( "X11Layout" ).toString().split( "," ).last();
+    currentVariant = locale1.property( "X11Variant" ).toString().split( "," ).last();
+    currentModel = locale1.property( "X11Model" ).toString();
+}
+
+void
+Config::detectCurrentKeyboardLayout()
+{
+    if ( m_state != State::Initial )
+    {
+        return;
+    }
+    cScopedAssignment returnToIntial( &m_state, State::Initial );
+    m_state = State::Guessing;
+
+    //### Detect current keyboard layout, variant, and model
+    QString currentLayout;
+    QString currentVariant;
+    QString currentModel;
+
+    if ( m_useLocale1 )
+    {
+        getCurrentKeyboardLayoutLocale1( currentLayout, currentVariant, currentModel );
+    }
+    else
+    {
+        getCurrentKeyboardLayoutXkb( currentLayout, currentVariant, currentModel );
+    }
 
     //### Layouts and Variants
     QPersistentModelIndex currentLayoutItem = findLayout( m_keyboardLayoutsModel, currentLayout );
@@ -352,20 +485,31 @@ Config::detectCurrentKeyboardLayout()
     {
         m_keyboardLayoutsModel->setCurrentIndex( m_keyboardLayoutsModel->index( 0 ).row() );
     }
+
+    //### Keyboard model
+    for ( int i = 0; i < m_keyboardModelsModel->rowCount(); ++i )
+    {
+        QModelIndex idx = m_keyboardModelsModel->index( i );
+        if ( idx.isValid() && idx.data( XKBListModel::KeyRole ).toString() == currentModel )
+        {
+            m_keyboardModelsModel->setCurrentIndex( idx.row() );
+            break;
+        }
+    }
 }
 
 QString
 Config::prettyStatus() const
 {
     QString status;
-    status += tr( "Set keyboard model to %1.<br/>" )
+    status += tr( "Keyboard model has been set to %1<br/>.", "@label, %1 is keyboard model, as in Apple Magic Keyboard" )
                   .arg( m_keyboardModelsModel->label( m_keyboardModelsModel->currentIndex() ) );
 
     QString layout = m_keyboardLayoutsModel->item( m_keyboardLayoutsModel->currentIndex() ).second.description;
     QString variant = m_keyboardVariantsModel->currentIndex() >= 0
         ? m_keyboardVariantsModel->label( m_keyboardVariantsModel->currentIndex() )
         : QString( "<default>" );
-    status += tr( "Set keyboard layout to %1/%2." ).arg( layout, variant );
+    status += tr( "Keyboard layout has been set to %1/%2.", "@label, %1 is layout, %2 is layout variant" ).arg( layout, variant );
 
     return status;
 }
@@ -381,7 +525,8 @@ Config::createJobs()
                                                   m_additionalLayoutInfo,
                                                   m_xOrgConfFileName,
                                                   m_convertedKeymapPath,
-                                                  m_writeEtcDefaultKeyboard );
+                                                  m_writeEtcDefaultKeyboard,
+                                                  m_useLocale1 );
     list.append( Calamares::job_ptr( j ) );
 
     return list;
@@ -430,7 +575,7 @@ guessLayout( const QStringList& langParts, KeyboardLayoutModel* layouts, Keyboar
 void
 Config::guessLocaleKeyboardLayout()
 {
-    if ( m_state != State::Initial )
+    if ( m_state != State::Initial || !m_guessLayout )
     {
         return;
     }
@@ -484,7 +629,7 @@ Config::guessLocaleKeyboardLayout()
 
     // Try to preselect a layout, depending on language and locale
     Calamares::GlobalStorage* gs = Calamares::JobQueue::instance()->globalStorage();
-    QString lang = CalamaresUtils::Locale::readGS( *gs, QStringLiteral( "LANG" ) );
+    QString lang = Calamares::Locale::readGS( *gs, QStringLiteral( "LANG" ) );
 
     cDebug() << "Got locale language" << lang;
     if ( !lang.isEmpty() )
@@ -531,7 +676,8 @@ Config::finalize()
         if ( !m_additionalLayoutInfo.additionalLayout.isEmpty() )
         {
             gs->insert( "keyboardAdditionalLayout", m_additionalLayoutInfo.additionalLayout );
-            gs->insert( "keyboardAdditionalLayout", m_additionalLayoutInfo.additionalVariant );
+            gs->insert( "keyboardAdditionalVariant", m_additionalLayoutInfo.additionalVariant );
+            gs->insert( "keyboardGroupSwitcher", m_additionalLayoutInfo.groupSwitcher );
             gs->insert( "keyboardVConsoleKeymap", m_additionalLayoutInfo.vconsoleKeymap );
         }
     }
@@ -560,7 +706,8 @@ Config::updateVariants( const QPersistentModelIndex& currentItem, QString curren
 void
 Config::setConfigurationMap( const QVariantMap& configurationMap )
 {
-    using namespace CalamaresUtils;
+    using namespace Calamares;
+    bool isX11 = QGuiApplication::platformName() == "xcb";
 
     const auto xorgConfDefault = QStringLiteral( "00-keyboard.conf" );
     m_xOrgConfFileName = getString( configurationMap, "xOrgConfFileName", xorgConfDefault );
@@ -570,6 +717,8 @@ Config::setConfigurationMap( const QVariantMap& configurationMap )
     }
     m_convertedKeymapPath = getString( configurationMap, "convertedKeymapPath" );
     m_writeEtcDefaultKeyboard = getBool( configurationMap, "writeEtcDefaultKeyboard", true );
+    m_useLocale1 = getBool( configurationMap, "useLocale1", !isX11 );
+    m_guessLayout = getBool( configurationMap, "guessLayout", true );
 }
 
 void
