@@ -17,6 +17,7 @@
 
 #include <QObject>
 
+class Config;
 class KeyboardPage;
 
 class PLUGINDLLEXPORT KeyboardViewStep : public Calamares::ViewStep
@@ -46,15 +47,8 @@ public:
     void setConfigurationMap( const QVariantMap& configurationMap ) override;
 
 private:
+    Config* m_config;
     KeyboardPage* m_widget;
-    bool m_nextEnabled;
-    QString m_prettyStatus;
-
-    QString m_xOrgConfFileName;
-    QString m_convertedKeymapPath;
-    bool m_writeEtcDefaultKeyboard;
-
-    Calamares::JobList m_jobs;
 };
 
 CALAMARES_PLUGIN_FACTORY_DECLARATION( KeyboardViewStepFactory )
