@@ -19,9 +19,9 @@
 
 #include "GlobalStorage.h"
 #include "JobQueue.h"
-#include "utils/CalamaresUtilsSystem.h"
 #include "utils/Logger.h"
 #include "utils/String.h"
+#include "utils/System.h"
 
 #include <QDir>
 #include <QFile>
@@ -29,6 +29,15 @@
 #include <QSettings>
 #include <QTextStream>
 
+namespace
+{
+QStringList
+removeEmpty( QStringList&& list )
+{
+    list.removeAll( QString() );
+    return list;
+}
+}  // namespace
 
 SetKeyboardLayoutJob::SetKeyboardLayoutJob( const QString& model,
                                             const QString& layout,
@@ -36,7 +45,8 @@ SetKeyboardLayoutJob::SetKeyboardLayoutJob( const QString& model,
                                             const AdditionalLayoutInfo& additionalLayoutInfo,
                                             const QString& xOrgConfFileName,
                                             const QString& convertedKeymapPath,
-                                            bool writeEtcDefaultKeyboard )
+                                            bool writeEtcDefaultKeyboard,
+                                            bool skipIfNoRoot )
     : Calamares::Job()
     , m_model( model )
     , m_layout( layout )
@@ -45,6 +55,7 @@ SetKeyboardLayoutJob::SetKeyboardLayoutJob( const QString& model,
     , m_xOrgConfFileName( xOrgConfFileName )
     , m_convertedKeymapPath( convertedKeymapPath )
     , m_writeEtcDefaultKeyboard( writeEtcDefaultKeyboard )
+    , m_skipIfNoRoot( skipIfNoRoot )
 {
 }
 
@@ -52,7 +63,8 @@ SetKeyboardLayoutJob::SetKeyboardLayoutJob( const QString& model,
 QString
 SetKeyboardLayoutJob::prettyName() const
 {
-    return tr( "Set keyboard model to %1, layout to %2-%3" ).arg( m_model ).arg( m_layout ).arg( m_variant );
+    return tr( "Setting keyboard model to %1, layout as %2-%3…", "@status, %1 model, %2 layout, %3 variant" )
+        .arg( m_model ).arg( m_layout ).arg( m_variant );
 }
 
 
@@ -175,7 +187,6 @@ SetKeyboardLayoutJob::findLegacyKeymap() const
     return ::findLegacyKeymap( m_layout, m_model, m_variant );
 }
 
-
 bool
 SetKeyboardLayoutJob::writeVConsoleData( const QString& vconsoleConfPath, const QString& convertedKeymapPath ) const
 {
@@ -266,32 +277,12 @@ SetKeyboardLayoutJob::writeX11Data( const QString& keyboardConfPath ) const
               "        MatchIsKeyboard \"on\"\n";
 
 
-    if ( m_additionalLayoutInfo.additionalLayout.isEmpty() )
+    const QStringList layouts = removeEmpty( { m_additionalLayoutInfo.additionalLayout, m_layout } );
+    const QStringList variants = removeEmpty( { m_additionalLayoutInfo.additionalVariant, m_variant } );
+    stream << "        Option \"XkbLayout\" \"" << layouts.join( "," ) << "\"\n";
+    stream << "        Option \"XkbVariant\" \"" << variants.join( "," ) << "\"\n";
+    if ( !m_additionalLayoutInfo.additionalLayout.isEmpty() )
     {
-        if ( !m_layout.isEmpty() )
-        {
-            stream << "        Option \"XkbLayout\" \"" << m_layout << "\"\n";
-        }
-
-        if ( !m_variant.isEmpty() )
-        {
-            stream << "        Option \"XkbVariant\" \"" << m_variant << "\"\n";
-        }
-    }
-    else
-    {
-        if ( !m_layout.isEmpty() )
-        {
-            stream << "        Option \"XkbLayout\" \"" << m_additionalLayoutInfo.additionalLayout << "," << m_layout
-                   << "\"\n";
-        }
-
-        if ( !m_variant.isEmpty() )
-        {
-            stream << "        Option \"XkbVariant\" \"" << m_additionalLayoutInfo.additionalVariant << "," << m_variant
-                   << "\"\n";
-        }
-
         stream << "        Option \"XkbOptions\" \"" << m_additionalLayoutInfo.groupSwitcher << "\"\n";
     }
 
@@ -300,8 +291,8 @@ SetKeyboardLayoutJob::writeX11Data( const QString& keyboardConfPath ) const
 
     file.close();
 
-    cDebug() << Logger::SubEntry << "Written XkbLayout" << m_layout << "; XkbModel" << m_model << "; XkbVariant"
-             << m_variant << "to X.org file" << keyboardConfPath << stream.status();
+    cDebug() << Logger::SubEntry << "Written XkbLayout" << layouts.join( "," ) << "; XkbModel" << m_model
+             << "; XkbVariant" << variants.join( "," ) << "to X.org file" << keyboardConfPath << stream.status();
 
     return ( stream.status() == QTextStream::Ok );
 }
@@ -320,20 +311,26 @@ SetKeyboardLayoutJob::writeDefaultKeyboardData( const QString& defaultKeyboardPa
     }
     QTextStream stream( &file );
 
+    const QStringList layouts = removeEmpty( { m_additionalLayoutInfo.additionalLayout, m_layout } );
+    const QStringList variants = removeEmpty( { m_additionalLayoutInfo.additionalVariant, m_variant } );
     stream << "# KEYBOARD CONFIGURATION FILE\n\n"
               "# Consult the keyboard(5) manual page.\n\n";
 
     stream << "XKBMODEL=\"" << m_model << "\"\n";
-    stream << "XKBLAYOUT=\"" << m_layout << "\"\n";
-    stream << "XKBVARIANT=\"" << m_variant << "\"\n";
-    stream << "XKBOPTIONS=\"\"\n\n";
+    stream << "XKBLAYOUT=\"" << layouts.join( "," ) << "\"\n";
+    stream << "XKBVARIANT=\"" << variants.join( "," ) << "\"\n";
+    if ( !m_additionalLayoutInfo.additionalLayout.isEmpty() )
+    {
+        stream << "XKBOPTIONS=\"" << m_additionalLayoutInfo.groupSwitcher << "\"\n";
+    }
     stream << "BACKSPACE=\"guess\"\n";
     stream.flush();
 
     file.close();
 
-    cDebug() << Logger::SubEntry << "Written XKBMODEL" << m_model << "; XKBLAYOUT" << m_layout << "; XKBVARIANT"
-             << m_variant << "to /etc/default/keyboard file" << defaultKeyboardPath << stream.status();
+    cDebug() << Logger::SubEntry << "Written XKBMODEL" << m_model << "; XKBLAYOUT" << layouts.join( "," )
+             << "; XKBVARIANT" << variants.join( "," ) << "to /etc/default/keyboard file" << defaultKeyboardPath
+             << stream.status();
 
     return ( stream.status() == QTextStream::Ok );
 }
@@ -348,6 +345,9 @@ SetKeyboardLayoutJob::exec()
     Calamares::GlobalStorage* gs = Calamares::JobQueue::instance()->globalStorage();
     QDir destDir( gs->value( "rootMountPoint" ).toString() );
 
+    // Skip this if we are using locale1 and we are configuring the local system,
+    // since the service will have already updated these configs for us.
+    if ( !( m_skipIfNoRoot && ( destDir.isEmpty() || destDir.isRoot() ) ) )
     {
         // Get the path to the destination's /etc/vconsole.conf
         QString vconsoleConfPath = destDir.absoluteFilePath( "etc/vconsole.conf" );
@@ -365,12 +365,10 @@ SetKeyboardLayoutJob::exec()
 
         if ( !writeVConsoleData( vconsoleConfPath, convertedKeymapPath ) )
         {
-            return Calamares::JobResult::error( tr( "Failed to write keyboard configuration for the virtual console." ),
-                                                tr( "Failed to write to %1" ).arg( vconsoleConfPath ) );
+            return Calamares::JobResult::error( tr( "Failed to write keyboard configuration for the virtual console.", "@error" ),
+                                                tr( "Failed to write to %1", "@error, %1 is virtual console configuration path" ).arg( vconsoleConfPath ) );
         }
-    }
 
-    {
         // Get the path to the destination's /etc/X11/xorg.conf.d/00-keyboard.conf
         QString xorgConfDPath;
         QString keyboardConfPath;
@@ -393,8 +391,8 @@ SetKeyboardLayoutJob::exec()
 
         if ( !writeX11Data( keyboardConfPath ) )
         {
-            return Calamares::JobResult::error( tr( "Failed to write keyboard configuration for X11." ),
-                                                tr( "Failed to write to %1" ).arg( keyboardConfPath ) );
+            return Calamares::JobResult::error( tr( "Failed to write keyboard configuration for X11.", "@error" ),
+                                                tr( "Failed to write to %1", "@error, %1 is keyboard configuration path" ).arg( keyboardConfPath ) );
         }
     }
 
@@ -410,8 +408,8 @@ SetKeyboardLayoutJob::exec()
             if ( !writeDefaultKeyboardData( defaultKeyboardPath ) )
             {
                 return Calamares::JobResult::error(
-                    tr( "Failed to write keyboard configuration to existing /etc/default directory." ),
-                    tr( "Failed to write to %1" ).arg( defaultKeyboardPath ) );
+                    tr( "Failed to write keyboard configuration to existing /etc/default directory.", "@error" ),
+                    tr( "Failed to write to %1", "@error, %1 is default keyboard path" ).arg( defaultKeyboardPath ) );
             }
         }
     }
