@@ -233,7 +233,7 @@ Config::setCurrentLocation()
 {
     if ( !m_currentLocation && m_startingTimezone.isValid() )
     {
-        setCurrentLocation( m_startingTimezone.first, m_startingTimezone.second );
+        setCurrentLocation( m_startingTimezone );
     }
     if ( !m_selectedLocaleConfiguration.explicit_lang )
     {
@@ -248,10 +248,16 @@ Config::setCurrentLocation( const QString& regionzone )
     auto r = Calamares::GeoIP::splitTZString( regionzone );
     if ( r.isValid() )
     {
-        setCurrentLocation( r.first, r.second );
+        setCurrentLocation( r );
     }
 }
 
+void
+Config::setCurrentLocation( const Calamares::GeoIP::RegionZonePair& tz )
+{
+    setCurrentLocation( tz.region(), tz.zone() );
+}
+
 void
 Config::setCurrentLocation( const QString& regionName, const QString& zoneName )
 {
@@ -407,13 +413,15 @@ localeLabel( const QString& s )
 QString
 Config::currentLanguageStatus() const
 {
-    return tr( "The system language will be set to %1.", "@info" ).arg( localeLabel( m_selectedLocaleConfiguration.language() ) );
+    return tr( "The system language will be set to %1.", "@info" )
+        .arg( localeLabel( m_selectedLocaleConfiguration.language() ) );
 }
 
 QString
 Config::currentLCStatus() const
 {
-    return tr( "The numbers and dates locale will be set to %1.", "@info" ).arg( localeLabel( m_selectedLocaleConfiguration.lc_numeric ) );
+    return tr( "The numbers and dates locale will be set to %1.", "@info" )
+        .arg( localeLabel( m_selectedLocaleConfiguration.lc_numeric ) );
 }
 
 QString
