@@ -20,7 +20,7 @@ LCLocaleDialog::LCLocaleDialog( const QString& guessedLCLocale, const QStringLis
     : QDialog( parent )
 {
     setModal( true );
-    setWindowTitle( tr( "System locale setting" ) );
+    setWindowTitle( tr( "System Locale Setting", "@title" ) );
 
     QBoxLayout* mainLayout = new QVBoxLayout;
     setLayout( mainLayout );
@@ -29,7 +29,7 @@ LCLocaleDialog::LCLocaleDialog( const QString& guessedLCLocale, const QStringLis
     upperText->setWordWrap( true );
     upperText->setText( tr( "The system locale setting affects the language and character "
                             "set for some command line user interface elements.<br/>"
-                            "The current setting is <strong>%1</strong>." )
+                            "The current setting is <strong>%1</strong>.", "@info" )
                             .arg( guessedLCLocale ) );
     mainLayout->addWidget( upperText );
     setMinimumWidth( upperText->fontMetrics().height() * 24 );
@@ -51,8 +51,8 @@ LCLocaleDialog::LCLocaleDialog( const QString& guessedLCLocale, const QStringLis
 
     QDialogButtonBox* dbb
         = new QDialogButtonBox( QDialogButtonBox::Ok | QDialogButtonBox::Cancel, Qt::Horizontal, this );
-    dbb->button( QDialogButtonBox::Cancel )->setText( tr( "&Cancel" ) );
-    dbb->button( QDialogButtonBox::Ok )->setText( tr( "&OK" ) );
+    dbb->button( QDialogButtonBox::Cancel )->setText( tr( "&Cancel", "@button" ) );
+    dbb->button( QDialogButtonBox::Ok )->setText( tr( "&OK", "@button" ) );
 
     mainLayout->addWidget( dbb );
 
@@ -84,5 +84,6 @@ LCLocaleDialog::LCLocaleDialog( const QString& guessedLCLocale, const QStringLis
 QString
 LCLocaleDialog::selectedLCLocale()
 {
-    return m_localesWidget->selectedItems().first()->text();
+    const auto items = m_localesWidget->selectedItems();
+    return items.isEmpty() ? QString{} : items.first()->text();
 }
