@@ -10,6 +10,7 @@
 
 #include "PackageModel.h"
 
+#include "compat/Variant.h"
 #include "utils/Logger.h"
 #include "utils/Variant.h"
 #include "utils/Yaml.h"
@@ -188,7 +189,7 @@ PackageModel::flags( const QModelIndex& index ) const
     if ( index.column() == NameColumn )
     {
         PackageTreeItem* item = static_cast< PackageTreeItem* >( index.internalPointer() );
-        if ( item->isImmutable() )
+        if ( item->isImmutable() || item->isNoncheckable() )
         {
             return QAbstractItemModel::flags( index );  //Qt::NoItemFlags;
         }
@@ -273,13 +274,13 @@ PackageModel::setupModelData( const QVariantList& groupList, PackageTreeItem* pa
         PackageTreeItem* item = new PackageTreeItem( groupMap, PackageTreeItem::GroupTag { parent } );
         if ( groupMap.contains( "selected" ) )
         {
-            item->setSelected( CalamaresUtils::getBool( groupMap, "selected", false ) ? Qt::Checked : Qt::Unchecked );
+            item->setSelected( Calamares::getBool( groupMap, "selected", false ) ? Qt::Checked : Qt::Unchecked );
         }
         if ( groupMap.contains( "packages" ) )
         {
             for ( const auto& packageName : groupMap.value( "packages" ).toList() )
             {
-                if ( packageName.type() == QVariant::String )
+                if ( Calamares::typeOf( packageName ) == Calamares::StringVariantType )
                 {
                     item->appendChild( new PackageTreeItem( packageName.toString(), item ) );
                 }
@@ -301,7 +302,7 @@ PackageModel::setupModelData( const QVariantList& groupList, PackageTreeItem* pa
         {
             bool haveWarned = false;
             const auto& subgroupValue = groupMap.value( "subgroups" );
-            if ( !subgroupValue.canConvert( QVariant::List ) )
+            if ( !subgroupValue.canConvert< QVariantList >() )
             {
                 cWarning() << "*subgroups* under" << item->name() << "is not a list.";
                 haveWarned = true;
@@ -349,11 +350,11 @@ PackageModel::setupModelData( const QVariantList& groupList, PackageTreeItem* pa
 void
 PackageModel::setupModelData( const QVariantList& l )
 {
-    Q_EMIT beginResetModel();
+    beginResetModel();
     delete m_rootItem;
     m_rootItem = new PackageTreeItem();
     setupModelData( l, m_rootItem );
-    Q_EMIT endResetModel();
+    endResetModel();
 }
 
 void
@@ -361,7 +362,7 @@ PackageModel::appendModelData( const QVariantList& groupList )
 {
     if ( m_rootItem )
     {
-        Q_EMIT beginResetModel();
+        beginResetModel();
 
         const QStringList sources = collectSources( groupList );
 
@@ -386,6 +387,6 @@ PackageModel::appendModelData( const QVariantList& groupList )
         // Add the new data to the model
         setupModelData( groupList, m_rootItem );
 
-        Q_EMIT endResetModel();
+        endResetModel();
     }
 }
