@@ -16,8 +16,8 @@
 #include "GlobalStorage.h"
 #include "JobQueue.h"
 #include "locale/TranslatableConfiguration.h"
-#include "utils/CalamaresUtilsSystem.h"
 #include "utils/Logger.h"
+#include "utils/System.h"
 #include "utils/Variant.h"
 
 #include <QDesktopServices>
