@@ -11,6 +11,7 @@
 #ifndef KPMHELPERS_H
 #define KPMHELPERS_H
 
+#include "Config.h"
 #include "Job.h"
 
 #include <kpmcore/core/partitiontable.h>
@@ -27,15 +28,10 @@ class Partition;
 class PartitionNode;
 class PartitionRole;
 
-#if defined( WITH_KPMCORE4API )
+// TODO:3.3: Remove defines, expand in-place
 #define KPM_PARTITION_FLAG( x ) PartitionTable::Flag::x
 #define KPM_PARTITION_STATE( x ) Partition::State::x
 #define KPM_PARTITION_FLAG_ESP PartitionTable::Flag::Boot
-#else
-#define KPM_PARTITION_FLAG( x ) PartitionTable::Flag##x
-#define KPM_PARTITION_STATE( x ) Partition::State##x
-#define KPM_PARTITION_FLAG_ESP PartitionTable::FlagEsp
-#endif
 
 /**
  * Helper functions to manipulate partitions
@@ -88,6 +84,7 @@ Partition* createNewEncryptedPartition( PartitionNode* parent,
                                         const QString& fsLabel,
                                         qint64 firstSector,
                                         qint64 lastSector,
+                                        Config::LuksGeneration luksFsType,
                                         const QString& passphrase,
                                         PartitionTable::Flags flags );
 
@@ -103,6 +100,37 @@ Partition* clonePartition( Device* device, Partition* partition );
  */
 SavePassphraseValue savePassphrase( Partition* partition, const QString& passphrase );
 
+/** @brief Decrypt an encrypted partition.
+ *
+ * Uses @p partition to decrypt the partition.
+ * The passphrase saved in @p partition is used.
+ * Returns the mapped device path or an empty string if it fails.
+ */
+QString cryptOpen( Partition* partition );
+void cryptClose( Partition* partition );
+
+/** @brief Set label of luks encrypted partition.
+ *
+ * Returns true on success or false if it fails.
+ */
+bool cryptLabel( Partition* partition, const QString& label );
+
+/** @brief Returns the luks version used to encrypt the partition.
+ *
+ * Used by cryptLabel
+ */
+int cryptVersion( Partition* partition );
+
+/** @brief Convert a luksGeneration into its FS type for KPMCore.
+ *
+ * Will convert Luks1 into FileSystem::Type::luks and Luks2 into
+ * FileSystem::Type::luks2 for KPMCore partitioning functions.
+ *
+ * @return The LUKS FS type (default @c luks )
+ */
+FileSystem::Type luksGenerationToFSName( Config::LuksGeneration luksGeneration );
+
+
 /** @brief Return a result for an @p operation
  *
  * Executes the operation, and if successful, returns a success result.
