@@ -8,11 +8,12 @@
  *
  */
 
-#include "core/PartitionModel.h"
+#include "PartitionModel.h"
 
 #include "core/ColorUtils.h"
 #include "core/KPMHelpers.h"
 #include "core/PartitionInfo.h"
+#include "core/SizeUtils.h"
 
 #include "partition/FileSystem.h"
 #include "partition/PartitionQuery.h"
@@ -24,14 +25,11 @@
 #include <kpmcore/core/partitiontable.h>
 #include <kpmcore/fs/filesystem.h>
 
-// KF5
-#include <KFormat>
-
 // Qt
 #include <QColor>
 
-using CalamaresUtils::Partition::isPartitionFreeSpace;
-using CalamaresUtils::Partition::isPartitionNew;
+using Calamares::Partition::isPartitionFreeSpace;
+using Calamares::Partition::isPartitionNew;
 
 //- ResetHelper --------------------------------------------
 PartitionModel::ResetHelper::ResetHelper( PartitionModel* model )
@@ -156,16 +154,16 @@ PartitionModel::data( const QModelIndex& index, int role ) const
         {
             if ( isPartitionFreeSpace( partition ) )
             {
-                return tr( "Free Space" );
+                return tr( "Free Space", "@title" );
             }
             else
             {
-                return isPartitionNew( partition ) ? tr( "New partition" ) : partition->partitionPath();
+                return isPartitionNew( partition ) ? tr( "New Partition", "@title" ) : partition->partitionPath();
             }
         }
         if ( col == FileSystemColumn )
         {
-            return CalamaresUtils::Partition::prettyNameForFileSystemType( partition->fileSystem().type() );
+            return Calamares::Partition::prettyNameForFileSystemType( partition->fileSystem().type() );
         }
         if ( col == FileSystemLabelColumn )
         {
@@ -178,7 +176,7 @@ PartitionModel::data( const QModelIndex& index, int role ) const
         if ( col == SizeColumn )
         {
             qint64 size = ( partition->lastSector() - partition->firstSector() + 1 ) * m_device->logicalSize();
-            return KFormat().formatByteSize( size );
+            return formatByteSize( size );
         }
         cDebug() << "Unknown column" << col;
         return QVariant();
@@ -200,17 +198,16 @@ PartitionModel::data( const QModelIndex& index, int role ) const
         {
             if ( isPartitionFreeSpace( partition ) )
             {
-                name = tr( "Free Space" );
+                name = tr( "Free Space", "@title" );
             }
             else
             {
-                name = isPartitionNew( partition ) ? tr( "New partition" ) : partition->partitionPath();
+                name = isPartitionNew( partition ) ? tr( "New Partition", "@title" ) : partition->partitionPath();
             }
         }
-        QString prettyFileSystem
-            = CalamaresUtils::Partition::prettyNameForFileSystemType( partition->fileSystem().type() );
+        QString prettyFileSystem = Calamares::Partition::prettyNameForFileSystemType( partition->fileSystem().type() );
         qint64 size = ( partition->lastSector() - partition->firstSector() + 1 ) * m_device->logicalSize();
-        QString prettySize = KFormat().formatByteSize( size );
+        QString prettySize = formatByteSize( size );
         return QVariant( name + " " + prettyFileSystem + " " + prettySize );
     }
     case SizeRole:
@@ -241,43 +238,53 @@ PartitionModel::data( const QModelIndex& index, int role ) const
     // Osprober roles:
     case OsproberNameRole:
         foreach ( const OsproberEntry& osproberEntry, m_osproberEntries )
+        {
             if ( partition->fileSystem().supportGetUUID() != FileSystem::cmdSupportNone
                  && !partition->fileSystem().uuid().isEmpty() && osproberEntry.uuid == partition->fileSystem().uuid() )
             {
                 return osproberEntry.prettyName;
             }
+        }
         return QVariant();
     case OsproberPathRole:
         foreach ( const OsproberEntry& osproberEntry, m_osproberEntries )
+        {
             if ( partition->fileSystem().supportGetUUID() != FileSystem::cmdSupportNone
                  && !partition->fileSystem().uuid().isEmpty() && osproberEntry.uuid == partition->fileSystem().uuid() )
             {
                 return osproberEntry.path;
             }
+        }
         return QVariant();
     case OsproberCanBeResizedRole:
         foreach ( const OsproberEntry& osproberEntry, m_osproberEntries )
+        {
             if ( partition->fileSystem().supportGetUUID() != FileSystem::cmdSupportNone
                  && !partition->fileSystem().uuid().isEmpty() && osproberEntry.uuid == partition->fileSystem().uuid() )
             {
                 return osproberEntry.canBeResized;
             }
+        }
         return QVariant();
     case OsproberRawLineRole:
         foreach ( const OsproberEntry& osproberEntry, m_osproberEntries )
+        {
             if ( partition->fileSystem().supportGetUUID() != FileSystem::cmdSupportNone
                  && !partition->fileSystem().uuid().isEmpty() && osproberEntry.uuid == partition->fileSystem().uuid() )
             {
                 return osproberEntry.line;
             }
+        }
         return QVariant();
     case OsproberHomePartitionPathRole:
         foreach ( const OsproberEntry& osproberEntry, m_osproberEntries )
+        {
             if ( partition->fileSystem().supportGetUUID() != FileSystem::cmdSupportNone
                  && !partition->fileSystem().uuid().isEmpty() && osproberEntry.uuid == partition->fileSystem().uuid() )
             {
                 return osproberEntry.homePath;
             }
+        }
         return QVariant();
         // end Osprober roles.
 
@@ -297,15 +304,15 @@ PartitionModel::headerData( int section, Qt::Orientation, int role ) const
     switch ( section )
     {
     case NameColumn:
-        return tr( "Name" );
+        return tr( "Name", "@title" );
     case FileSystemColumn:
-        return tr( "File System" );
+        return tr( "File System", "@title" );
     case FileSystemLabelColumn:
-        return tr( "File System Label" );
+        return tr( "File System Label", "@title" );
     case MountPointColumn:
-        return tr( "Mount Point" );
+        return tr( "Mount Point", "@title" );
     case SizeColumn:
-        return tr( "Size" );
+        return tr( "Size", "@title" );
     default:
         cDebug() << "Unknown column" << section;
         return QVariant();
