@@ -2,21 +2,23 @@
  *
  *   SPDX-FileCopyrightText: 2016 Teo Mrnjavac <teo@kde.org>
  *   SPDX-FileCopyrightText: 2020 Adriaan de Groot <groot@kde.org>
+ *   SPDX-FileCopyrightText: 2023 Evan James <dalto@fastmail.com>
  *   SPDX-License-Identifier: GPL-3.0-or-later
  *
  *   Calamares is Free Software: see the License-Identifier above.
  *
  */
 
-
 #include "EncryptWidget.h"
 
 #include "ui_EncryptWidget.h"
 
 #include "Branding.h"
-#include "utils/CalamaresUtilsGui.h"
+#include "utils/Gui.h"
 #include "utils/Retranslator.h"
 
+constexpr int ZFS_MIN_LENGTH = 8;
+
 /** @brief Does this system support whole-disk encryption?
  *
  * Returns @c true if the system is likely to support encryption
@@ -68,7 +70,6 @@ EncryptWidget::EncryptWidget( QWidget* parent )
     CALAMARES_RETRANSLATE_SLOT( &EncryptWidget::retranslate );
 }
 
-
 void
 EncryptWidget::reset( bool checkVisible )
 {
@@ -85,70 +86,8 @@ EncryptWidget::reset( bool checkVisible )
 EncryptWidget::Encryption
 EncryptWidget::state() const
 {
-    return m_state;
-}
+    Encryption newState = Encryption::Unconfirmed;
 
-
-void
-EncryptWidget::setText( const QString& text )
-{
-    m_ui->m_encryptCheckBox->setText( text );
-}
-
-
-QString
-EncryptWidget::passphrase() const
-{
-    if ( m_state == Encryption::Confirmed )
-    {
-        return m_ui->m_passphraseLineEdit->text();
-    }
-    return QString();
-}
-
-
-void
-EncryptWidget::retranslate()
-{
-    m_ui->retranslateUi( this );
-    onPassphraseEdited();  // For the tooltip
-}
-
-
-///@brief Give @p label the @p pixmap from the standard-pixmaps
-static void
-applyPixmap( QLabel* label, CalamaresUtils::ImageType pixmap )
-{
-    label->setFixedWidth( label->height() );
-    label->setPixmap( CalamaresUtils::defaultPixmap( pixmap, CalamaresUtils::Original, label->size() ) );
-}
-
-void
-EncryptWidget::updateState()
-{
-    if ( m_ui->m_passphraseLineEdit->isVisible() )
-    {
-        QString p1 = m_ui->m_passphraseLineEdit->text();
-        QString p2 = m_ui->m_confirmLineEdit->text();
-
-        if ( p1.isEmpty() && p2.isEmpty() )
-        {
-            applyPixmap( m_ui->m_iconLabel, CalamaresUtils::StatusWarning );
-            m_ui->m_iconLabel->setToolTip( tr( "Please enter the same passphrase in both boxes." ) );
-        }
-        else if ( p1 == p2 )
-        {
-            applyPixmap( m_ui->m_iconLabel, CalamaresUtils::StatusOk );
-            m_ui->m_iconLabel->setToolTip( QString() );
-        }
-        else
-        {
-            applyPixmap( m_ui->m_iconLabel, CalamaresUtils::StatusError );
-            m_ui->m_iconLabel->setToolTip( tr( "Please enter the same passphrase in both boxes." ) );
-        }
-    }
-
-    Encryption newState;
     if ( m_ui->m_encryptCheckBox->isChecked() || !m_ui->m_encryptCheckBox->isVisible() )
     {
         if ( !m_ui->m_passphraseLineEdit->text().isEmpty()
@@ -166,10 +105,79 @@ EncryptWidget::updateState()
         newState = Encryption::Disabled;
     }
 
+    return newState;
+}
+
+void
+EncryptWidget::setText( const QString& text )
+{
+    m_ui->m_encryptCheckBox->setText( text );
+}
+
+QString
+EncryptWidget::passphrase() const
+{
+    if ( m_state == Encryption::Confirmed )
+    {
+        return m_ui->m_passphraseLineEdit->text();
+    }
+    return QString();
+}
+
+void
+EncryptWidget::retranslate()
+{
+    m_ui->retranslateUi( this );
+    onPassphraseEdited();  // For the tooltip
+}
+
+///@brief Give @p label the @p pixmap from the standard-pixmaps
+static void
+applyPixmap( QLabel* label, Calamares::ImageType pixmap )
+{
+    label->setFixedWidth( label->height() );
+    label->setPixmap( Calamares::defaultPixmap( pixmap, Calamares::Original, label->size() ) );
+}
+
+void
+EncryptWidget::updateState( const bool notify )
+{
+    if ( m_ui->m_passphraseLineEdit->isVisible() )
+    {
+        QString p1 = m_ui->m_passphraseLineEdit->text();
+        QString p2 = m_ui->m_confirmLineEdit->text();
+
+        if ( p1.isEmpty() && p2.isEmpty() )
+        {
+            applyPixmap( m_ui->m_iconLabel, Calamares::StatusWarning );
+            m_ui->m_iconLabel->setToolTip( tr( "Please enter the same passphrase in both boxes.", "@tooltip" ) );
+        }
+        else if ( m_filesystem == FileSystem::Zfs && p1.length() < ZFS_MIN_LENGTH )
+        {
+            applyPixmap( m_ui->m_iconLabel, Calamares::StatusError );
+            m_ui->m_iconLabel->setToolTip( tr( "Password must be a minimum of %1 characters.", "@tooltip" ).arg( ZFS_MIN_LENGTH ) );
+        }
+        else if ( p1 == p2 )
+        {
+            applyPixmap( m_ui->m_iconLabel, Calamares::StatusOk );
+            m_ui->m_iconLabel->setToolTip( QString() );
+        }
+        else
+        {
+            applyPixmap( m_ui->m_iconLabel, Calamares::StatusError );
+            m_ui->m_iconLabel->setToolTip( tr( "Please enter the same passphrase in both boxes.", "@tooltip" ) );
+        }
+    }
+
+    Encryption newState = state();
+
     if ( newState != m_state )
     {
         m_state = newState;
-        Q_EMIT stateChanged( m_state );
+        if ( notify )
+        {
+            Q_EMIT stateChanged( m_state );
+        }
     }
 }
 
@@ -184,7 +192,6 @@ EncryptWidget::onPassphraseEdited()
     updateState();
 }
 
-
 void
 EncryptWidget::onCheckBoxStateChanged( int checked )
 {
@@ -198,3 +205,13 @@ EncryptWidget::onCheckBoxStateChanged( int checked )
 
     updateState();
 }
+
+void
+EncryptWidget::setFilesystem( const FileSystem::Type fs )
+{
+    m_filesystem = fs;
+    if ( m_state != Encryption::Disabled )
+    {
+        updateState( false );
+    }
+}
