@@ -10,7 +10,7 @@
 
 #include "ScanningDialog.h"
 
-#include "3rdparty/waitingspinnerwidget.h"
+#include "widgets/waitingspinnerwidget.h"
 
 #include <QBoxLayout>
 #include <QFutureWatcher>
@@ -47,12 +47,16 @@ ScanningDialog::run( const QFuture< void >& future,
     theDialog->show();
 
     QFutureWatcher< void >* watcher = new QFutureWatcher< void >();
-    connect( watcher, &QFutureWatcher< void >::finished, theDialog, [watcher, theDialog, callback] {
-        watcher->deleteLater();
-        theDialog->hide();
-        theDialog->deleteLater();
-        callback();
-    } );
+    connect( watcher,
+             &QFutureWatcher< void >::finished,
+             theDialog,
+             [ watcher, theDialog, callback ]
+             {
+                 watcher->deleteLater();
+                 theDialog->hide();
+                 theDialog->deleteLater();
+                 callback();
+             } );
 
     watcher->setFuture( future );
 }
@@ -61,7 +65,7 @@ ScanningDialog::run( const QFuture< void >& future,
 void
 ScanningDialog::run( const QFuture< void >& future, const std::function< void() >& callback, QWidget* parent )
 {
-    ScanningDialog::run( future, tr( "Scanning storage devices..." ), tr( "Partitioning" ), callback, parent );
+    ScanningDialog::run( future, tr( "Scanning storage devices…", "@status" ), tr( "Partitioning…", "@status" ), callback, parent );
 }
 
 void
