@@ -19,22 +19,22 @@ AutoMountManagementJob::AutoMountManagementJob( bool disable )
 QString
 AutoMountManagementJob::prettyName() const
 {
-    return tr( "Manage auto-mount settings" );
+    return tr( "Managing auto-mount settings…", "@status" );
 }
 
 Calamares::JobResult
 AutoMountManagementJob::exec()
 {
-    cVerbose() << "this" << Logger::Pointer( this ) << "value" << Logger::Pointer( m_stored )
-               << ( m_stored ? "restore" : m_disable ? "disable" : "enable" );
     if ( m_stored )
     {
-        CalamaresUtils::Partition::automountRestore( m_stored );
+        cDebug() << "Restore automount settings";
+        Calamares::Partition::automountRestore( m_stored );
         m_stored.reset();
     }
     else
     {
-        m_stored = CalamaresUtils::Partition::automountDisable( m_disable );
+        cDebug() << "Set automount to" << ( m_disable ? "disable" : "enable" );
+        m_stored = Calamares::Partition::automountDisable( m_disable );
     }
     return Calamares::JobResult::ok();
 }
