@@ -24,10 +24,9 @@
 
 QTEST_GUILESS_MAIN( ShellProcessTests )
 
-using CommandList = CalamaresUtils::CommandList;
+using CommandList = Calamares::CommandList;
 using std::operator""s;
 
-
 ShellProcessTests::ShellProcessTests() {}
 
 ShellProcessTests::~ShellProcessTests() {}
@@ -40,43 +39,43 @@ ShellProcessTests::initTestCase()
 void
 ShellProcessTests::testProcessListSampleConfig()
 {
-    YAML::Node doc;
+    ::YAML::Node doc;
 
     QString filename = QStringLiteral( "shellprocess.conf" );
     QFile fi( QString( "%1/%2" ).arg( BUILD_AS_TEST, filename ) );
 
     QVERIFY( fi.exists() );
-    doc = YAML::LoadFile( fi.fileName().toStdString() );
+    doc = ::YAML::LoadFile( fi.fileName().toStdString() );
 
-    CommandList cl( CalamaresUtils::yamlMapToVariant( doc ).value( "script" ) );
+    CommandList cl( Calamares::YAML::mapToVariant( doc ).value( "script" ) );
     QVERIFY( !cl.isEmpty() );
     QCOMPARE( cl.count(), 3 );
 
-    QCOMPARE( cl.at( 0 ).timeout(), CalamaresUtils::CommandLine::TimeoutNotSet() );
+    QCOMPARE( cl.at( 0 ).timeout(), Calamares::CommandLine::TimeoutNotSet() );
     QCOMPARE( cl.at( 2 ).timeout(), 3600s );  // slowloris
 }
 
 void
 ShellProcessTests::testProcessListFromList()
 {
-    YAML::Node doc = YAML::Load( R"(---
+    ::YAML::Node doc = ::YAML::Load( R"(---
 script:
     - "ls /tmp"
     - "ls /nonexistent"
     - "/bin/false"
 )" );
-    CommandList cl( CalamaresUtils::yamlMapToVariant( doc ).value( "script" ) );
+    CommandList cl( Calamares::YAML::mapToVariant( doc ).value( "script" ) );
     QVERIFY( !cl.isEmpty() );
     QCOMPARE( cl.count(), 3 );
 
     // Contains 1 bad element
-    doc = YAML::Load( R"(---
+    doc = ::YAML::Load( R"(---
 script:
     - "ls /tmp"
     - false
     - "ls /nonexistent"
 )" );
-    CommandList cl1( CalamaresUtils::yamlMapToVariant( doc ).value( "script" ) );
+    CommandList cl1( Calamares::YAML::mapToVariant( doc ).value( "script" ) );
     QVERIFY( !cl1.isEmpty() );
     QCOMPARE( cl1.count(), 2 );  // One element ignored
 }
@@ -87,7 +86,7 @@ ShellProcessTests::testProcessListFromString()
     YAML::Node doc = YAML::Load( R"(---
 script: "ls /tmp"
 )" );
-    CommandList cl( CalamaresUtils::yamlMapToVariant( doc ).value( "script" ) );
+    CommandList cl( Calamares::YAML::mapToVariant( doc ).value( "script" ) );
 
     QVERIFY( !cl.isEmpty() );
     QCOMPARE( cl.count(), 1 );
@@ -98,7 +97,7 @@ script: "ls /tmp"
     doc = YAML::Load( R"(---
 script: false
 )" );
-    CommandList cl1( CalamaresUtils::yamlMapToVariant( doc ).value( "script" ) );
+    CommandList cl1( Calamares::YAML::mapToVariant( doc ).value( "script" ) );
     QVERIFY( cl1.isEmpty() );
     QCOMPARE( cl1.count(), 0 );
 }
@@ -111,7 +110,7 @@ script:
     command: "ls /tmp"
     timeout: 20
 )" );
-    CommandList cl( CalamaresUtils::yamlMapToVariant( doc ).value( "script" ) );
+    CommandList cl( Calamares::YAML::mapToVariant( doc ).value( "script" ) );
 
     QVERIFY( !cl.isEmpty() );
     QCOMPARE( cl.count(), 1 );
@@ -128,12 +127,12 @@ script:
       timeout: 12
     - "-/bin/false"
 )" );
-    CommandList cl( CalamaresUtils::yamlMapToVariant( doc ).value( "script" ) );
+    CommandList cl( Calamares::YAML::mapToVariant( doc ).value( "script" ) );
     QVERIFY( !cl.isEmpty() );
     QCOMPARE( cl.count(), 2 );
     QCOMPARE( cl.at( 0 ).timeout(), 12s );
     QCOMPARE( cl.at( 0 ).command(), QStringLiteral( "ls /tmp" ) );
-    QCOMPARE( cl.at( 1 ).timeout(), CalamaresUtils::CommandLine::TimeoutNotSet() );  // not set
+    QCOMPARE( cl.at( 1 ).timeout(), Calamares::CommandLine::TimeoutNotSet() );  // not set
 }
 
 void
@@ -143,37 +142,41 @@ ShellProcessTests::testRootSubstitution()
 script:
     - "ls /tmp"
 )" );
-    QVariant plainScript = CalamaresUtils::yamlMapToVariant( doc ).value( "script" );
-    QVariant rootScript = CalamaresUtils::yamlMapToVariant( YAML::Load( R"(---
+    QVariant plainScript = Calamares::YAML::mapToVariant( doc ).value( "script" );
+    QVariant rootScript = Calamares::YAML::mapToVariant( YAML::Load( R"(---
 script:
-    - "ls @@ROOT@@"
+    - "ls ${ROOT}"
 )" ) )
                               .value( "script" );
-    QVariant userScript = CalamaresUtils::yamlMapToVariant( YAML::Load( R"(---
+    QVariant userScript = Calamares::YAML::mapToVariant( YAML::Load( R"(---
 script:
-    - mktemp -d @@ROOT@@/calatestXXXXXXXX
-    - "chown @@USER@@ @@ROOT@@/calatest*"
-    - rm -rf @@ROOT@@/calatest*
+    - mktemp -d ${ROOT}/calatestXXXXXXXX
+    - "chown ${USER} ${ROOT}/calatest*"
+    - rm -rf ${ROOT}/calatest*
 )" ) )
                               .value( "script" );
 
     if ( !Calamares::JobQueue::instance() )
+    {
         (void)new Calamares::JobQueue( nullptr );
+    }
     if ( !Calamares::Settings::instance() )
+    {
         (void)Calamares::Settings::init( QString() );
+    }
 
     Calamares::GlobalStorage* gs = Calamares::JobQueue::instance()->globalStorage();
     QVERIFY( gs != nullptr );
 
     qDebug() << "Expect WARNING, ERROR, WARNING";
 
-    // Doesn't use @@ROOT@@, so no failures
+    // Doesn't use ${ROOT}, so no failures
     QVERIFY( bool( CommandList( plainScript, false, 10s ).run() ) );
 
-    // Doesn't use @@ROOT@@, but does chroot, so fails
+    // Doesn't use ${ROOT}, but does chroot, so fails
     QVERIFY( !bool( CommandList( plainScript, true, 10s ).run() ) );
 
-    // Does use @@ROOT@@, which is not set, so fails
+    // Does use ${ROOT}, which is not set, so fails
     QVERIFY( !bool( CommandList( rootScript, false, 10s ).run() ) );
     // .. fails for two reasons
     QVERIFY( !bool( CommandList( rootScript, true, 10s ).run() ) );
@@ -190,7 +193,14 @@ script:
     // But no user set yet
     QVERIFY( !bool( CommandList( userScript, false, 10s ).run() ) );
 
-    // Now play dangerous games with shell expansion
+    // Show that shell expansion is now quoted.
     gs->insert( "username", "`id -u`" );
-    QVERIFY( bool( CommandList( userScript, false, 10s ).run() ) );
+    {
+        Calamares::CommandLine c { QStringLiteral( "chown ${USER}" ), std::chrono::seconds( 0 ) };
+        QCOMPARE( c.expand().command(), QStringLiteral( "chown '`id -u`'" ) );
+    }
+    // Now play dangerous games with shell expansion -- except the internal command is now
+    // quoted, so this fails because it's **highly** unlikely that the literal string
+    // "`id -u`" is a valid username.
+    QVERIFY( !bool( CommandList( userScript, false, 10s ).run() ) );
 }
