@@ -14,10 +14,13 @@
 
 #include <QWidget>
 
+class Config;
+class SummaryViewStep;
+
 class QLabel;
 class QScrollArea;
 class QVBoxLayout;
-class SummaryViewStep;
+
 
 /** @brief Provide a summary view with to-be-done action descriptions.
 *
@@ -42,23 +45,17 @@ class SummaryPage : public QWidget
 {
     Q_OBJECT
 public:
-    explicit SummaryPage( const SummaryViewStep* thisViewStep, QWidget* parent = nullptr );
+    explicit SummaryPage( Config* config, QWidget* parent = nullptr );
 
-    void onActivate();
-    void createContentWidget();
+    /// @brief Create contents showing all of the summary
+    void buildWidgets( Config* config, SummaryViewStep* viewstep );
+    /// @brief Clean up the widgets
+    void cleanup();
 
 private:
-    Calamares::ViewStepList stepsForSummary( const Calamares::ViewStepList& allSteps ) const;
-
-    const SummaryViewStep* m_thisViewStep;
-
     QVBoxLayout* m_layout = nullptr;
     QWidget* m_contentWidget = nullptr;
-
-    QLabel* createTitleLabel( const QString& text ) const;
-    QLabel* createBodyLabel( const QString& text ) const;
-
-    QScrollArea* m_scrollArea;
+    QScrollArea* m_scrollArea = nullptr;
 };
 
 #endif  // SUMMARYPAGE_H
