@@ -36,13 +36,13 @@ CreateUserJob::prettyName() const
 QString
 CreateUserJob::prettyDescription() const
 {
-    return tr( "Create user <strong>%1</strong>." ).arg( m_config->loginName() );
+    return tr( "Create user <strong>%1</strong>" ).arg( m_config->loginName() );
 }
 
 QString
 CreateUserJob::prettyStatusMessage() const
 {
-    return m_status.isEmpty() ? tr( "Creating user %1" ).arg( m_config->loginName() ) : m_status;
+    return m_status.isEmpty() ? tr( "Creating user %1…", "@status" ).arg( m_config->loginName() ) : m_status;
 }
 
 static Calamares::JobResult
@@ -117,7 +117,7 @@ CreateUserJob::exec()
     // This GS setting comes from the **partitioning** module.
     if ( reuseHome )
     {
-        m_status = tr( "Preserving home directory" );
+        m_status = tr( "Preserving home directory…", "@status" );
         emit progress( 0.2 );
         QString shellFriendlyHome = "/home/" + m_config->loginName();
         QDir existingHome( destDir.absolutePath() + shellFriendlyHome );
@@ -134,7 +134,7 @@ CreateUserJob::exec()
 
     cDebug() << "[CREATEUSER]: creating user";
 
-    m_status = tr( "Creating user %1" ).arg( m_config->loginName() );
+    m_status = tr( "Creating user %1…", "@status" ).arg( m_config->loginName() );
     emit progress( 0.5 );
     auto useraddResult = createUser( m_config->loginName(), m_config->fullName(), m_config->userShell() );
     if ( !useraddResult )
@@ -142,7 +142,7 @@ CreateUserJob::exec()
         return useraddResult;
     }
 
-    m_status = tr( "Configuring user %1" ).arg( m_config->loginName() );
+    m_status = tr( "Configuring user %1", "@status" ).arg( m_config->loginName() );
     emit progress( 0.8 );
     auto usergroupsResult = setUserGroups( m_config->loginName(), m_config->groupsForThisUser() );
     if ( !usergroupsResult )
@@ -150,7 +150,7 @@ CreateUserJob::exec()
         return usergroupsResult;
     }
 
-    m_status = tr( "Setting file permissions" );
+    m_status = tr( "Setting file permissions…", "@status" );
     emit progress( 0.9 );
     QString userGroup = QString( "%1:%2" ).arg( m_config->loginName() ).arg( m_config->loginName() );
     QString homeDir = QString( "/home/%1" ).arg( m_config->loginName() );
