@@ -53,6 +53,9 @@ private Q_SLOTS:
 
     void testAutoLogin_data();
     void testAutoLogin();
+
+    void testUserYAML_data();
+    void testUserYAML();
 };
 
 UserTests::UserTests() {}
@@ -117,12 +120,16 @@ UserTests::testGetSet()
         QVERIFY( c.loginNameStatus().isEmpty() );  // now it's still ok
         QCOMPARE( c.loginName(), lg );
         QCOMPARE( c.fullName(), ful );
+    }
+    // Test forbidden login names
+    {
+        QVERIFY( c.forbiddenLoginNames().contains( QStringLiteral( "root" ) ) );
+        QVERIFY( c.loginNameStatus().isEmpty() );  // it's ok now
         c.setLoginName( "root" );
         QVERIFY( !c.loginNameStatus().isEmpty() );  // can't be root
     }
 }
 
-
 void
 UserTests::testDefaultGroups()
 {
@@ -206,11 +213,11 @@ UserTests::testDefaultGroupsYAML()
     QFETCH( QString, group );
 
     // BUILD_AS_TEST is the source-directory path
-    QFile fi( QString( "%1/%2" ).arg( BUILD_AS_TEST, filename ) );
+    QFileInfo fi( QString( "%1/%2" ).arg( BUILD_AS_TEST, filename ) );
     QVERIFY( fi.exists() );
 
     bool ok = false;
-    const auto map = CalamaresUtils::loadYaml( fi, &ok );
+    const auto map = Calamares::YAML::load( fi, &ok );
     QVERIFY( ok );
     QVERIFY( map.count() > 0 );
 
@@ -221,7 +228,6 @@ UserTests::testDefaultGroupsYAML()
     QVERIFY( c.defaultGroups().contains( group ) );
 }
 
-
 void
 UserTests::testHostActions_data()
 {
@@ -276,14 +282,15 @@ UserTests::testHostActions2()
     QCOMPARE( c.hostnameAction(), HostNameAction::EtcHostname );
     QCOMPARE( c.writeEtcHosts(), true );
 
-    legacy.insert( "writeHostsFile", false );
-    legacy.insert( "setHostname", "Hostnamed" );
+    QVariantMap hostSettings;
+    hostSettings.insert( "writeHostsFile", false );
+    hostSettings.insert( "location", "Hostnamed" );
+    legacy.insert( "hostname", hostSettings );
     c.setConfigurationMap( legacy );
     QCOMPARE( c.hostnameAction(), HostNameAction::SystemdHostname );
     QCOMPARE( c.writeEtcHosts(), false );
 }
 
-
 void
 UserTests::testHostSuggestions_data()
 {
@@ -298,7 +305,8 @@ UserTests::testHostSuggestions_data()
     QTest::newRow( "full   " ) << QStringLiteral( "${name}" ) << QStringLiteral( "chuckyeager" );
     QTest::newRow( "login+ " ) << QStringLiteral( "${login}-${first}" ) << QStringLiteral( "bill-chuck" );
     // This is a bit dodgy: assumes CPU architecture of the testing host
-    QTest::newRow( " cpu   " ) << QStringLiteral( "${cpu}X" ) << QStringLiteral( "x8664X" );  // Assume we don't test on non-amd64
+    QTest::newRow( " cpu   " ) << QStringLiteral( "${cpu}X" )
+                               << QStringLiteral( "x8664X" );  // Assume we don't test on non-amd64
     // These have X X in the template to indicate that they are bogus. Mostly we want
     // to see what the template engine does for these.
     QTest::newRow( "@prod  " ) << QStringLiteral( "X${product}X" ) << QString();
@@ -315,25 +323,25 @@ UserTests::testHostSuggestions()
     QFETCH( QString, templateString );
     QFETCH( QString, result );
 
-    if ( templateString.startsWith('X') && templateString.endsWith('X'))
+    if ( templateString.startsWith( 'X' ) && templateString.endsWith( 'X' ) )
     {
         QEXPECT_FAIL( "", "Test is too host-specific", Continue );
-        cWarning() << Logger::SubEntry << "Next test" << templateString << "->" << makeHostnameSuggestion( templateString, fullName, login );
+        cWarning() << Logger::SubEntry << "Next test" << templateString << "->"
+                   << makeHostnameSuggestion( templateString, fullName, login );
     }
     QCOMPARE( makeHostnameSuggestion( templateString, fullName, login ), result );
 }
 
-
 void
 UserTests::testPasswordChecks()
 {
     {
         PasswordCheckList l;
         QCOMPARE( l.length(), 0 );
-        QVERIFY( !addPasswordCheck( "nonempty", QVariant( false ), l ) );  // a silly setting
+        QVERIFY( !addPasswordCheck( "nonempty", QVariant( false ), l ) );  // legacy option, now ignored
+        QCOMPARE( l.length(), 0 );
+        QVERIFY( !addPasswordCheck( "nonempty", QVariant( true ), l ) ); // still ignored
         QCOMPARE( l.length(), 0 );
-        QVERIFY( addPasswordCheck( "nonempty", QVariant( true ), l ) );
-        QCOMPARE( l.length(), 1 );
     }
 }
 
@@ -438,11 +446,11 @@ UserTests::testAutoLogin()
     QFETCH( QString, autoLoginGroupName );
 
     // BUILD_AS_TEST is the source-directory path
-    QFile fi( QString( "%1/%2" ).arg( BUILD_AS_TEST, filename ) );
+    QFileInfo fi( QString( "%1/%2" ).arg( BUILD_AS_TEST, filename ) );
     QVERIFY( fi.exists() );
 
     bool ok = false;
-    const auto map = CalamaresUtils::loadYaml( fi, &ok );
+    const auto map = Calamares::YAML::load( fi, &ok );
     QVERIFY( ok );
     QVERIFY( map.count() > 0 );
 
@@ -453,6 +461,55 @@ UserTests::testAutoLogin()
     QCOMPARE( c.autoLoginGroup(), autoLoginGroupName );
 }
 
+void
+UserTests::testUserYAML_data()
+{
+    QTest::addColumn< QString >( "filename" );
+    QTest::addColumn< QString >( "shell" );
+
+    const QString bash = QStringLiteral( "/bin/bash" );
+
+    // All the old settings are ignored
+    QTest::newRow( "old, unset   " ) << "tests/7ao-shell.conf" << bash;
+    QTest::newRow( "old, empty   " ) << "tests/7bo-shell.conf" << bash;
+    QTest::newRow( "old, relative" ) << "tests/7co-shell.conf" << bash;
+    QTest::newRow( "old, invalid " ) << "tests/7do-shell.conf" << bash;
+    QTest::newRow( "old, absolute" ) << "tests/7eo-shell.conf" << bash;
+
+    QTest::newRow( "new, unset   " ) << "tests/7an-shell.conf"
+                                     << "/bin/bash";
+    QTest::newRow( "new, empty   " ) << "tests/7bn-shell.conf"
+                                     << "";
+    QTest::newRow( "new, relative" ) << "tests/7cn-shell.conf"
+                                     << "/bin/ls";  // Setting is ignored
+    QTest::newRow( "new, invalid " ) << "tests/7dn-shell.conf"
+                                     << "";
+    QTest::newRow( "new, absolute" ) << "tests/7en-shell.conf"
+                                     << "/usr/bin/dash";
+}
+
+void
+UserTests::testUserYAML()
+{
+    Config c;
+    c.setUserShell( QStringLiteral( "/bin/ls" ) );
+
+    QFETCH( QString, filename );
+    QFETCH( QString, shell );
+
+    // BUILD_AS_TEST is the source-directory path
+    QFileInfo fi( QString( "%1/%2" ).arg( BUILD_AS_TEST, filename ) );
+    QVERIFY( fi.exists() );
+
+    bool ok = false;
+    const auto map = Calamares::YAML::load( fi, &ok );
+    QVERIFY( ok );
+    QVERIFY( map.count() > 0 );
+
+    QCOMPARE( c.userShell(), QStringLiteral( "/bin/ls" ) );
+    c.setConfigurationMap( map );
+    QCOMPARE( c.userShell(), shell );
+}
 
 QTEST_GUILESS_MAIN( UserTests )
 
