@@ -10,9 +10,11 @@
 #include "Config.h"
 
 #include "Branding.h"
+#include "CalamaresAbout.h"
 #include "GlobalStorage.h"
 #include "JobQueue.h"
 #include "Settings.h"
+#include "compat/Variant.h"
 #include "geoip/Handler.h"
 #include "locale/Global.h"
 #include "locale/Lookup.h"
@@ -25,7 +27,7 @@
 
 Config::Config( QObject* parent )
     : QObject( parent )
-    , m_languages( CalamaresUtils::Locale::availableTranslations() )
+    , m_languages( Calamares::Locale::availableTranslations() )
     , m_filtermodel( std::make_unique< QSortFilterProxyModel >() )
     , m_requirementsChecker( std::make_unique< GeneralRequirements >( this ) )
 {
@@ -54,12 +56,10 @@ Config::retranslate()
         {
             message = setup ? tr( "This computer does not satisfy the minimum "
                                   "requirements for setting up %1.<br/>"
-                                  "Setup cannot continue. "
-                                  "<a href=\"#details\">Details...</a>" )
+                                  "Setup cannot continue." )
                             : tr( "This computer does not satisfy the minimum "
                                   "requirements for installing %1.<br/>"
-                                  "Installation cannot continue. "
-                                  "<a href=\"#details\">Details...</a>" );
+                                  "Installation cannot continue." );
         }
         else
         {
@@ -85,7 +85,7 @@ Config::retranslate()
     emit warningMessageChanged( m_warningMessage );
 }
 
-CalamaresUtils::Locale::TranslationsModel*
+Calamares::Locale::TranslationsModel*
 Config::languagesModel() const
 {
     return m_languages;
@@ -110,7 +110,6 @@ Config::unsatisfiedRequirements() const
     return m_filtermodel.get();
 }
 
-
 QString
 Config::languageIcon() const
 {
@@ -121,7 +120,7 @@ void
 Config::initLanguages()
 {
     // Find the best initial translation
-    CalamaresUtils::Locale::Translation defaultTranslation;
+    Calamares::Locale::Translation defaultTranslation;
 
     cDebug() << "Trying to match locale" << defaultTranslation.id();
     int matchedLocaleIndex = m_languages->find( defaultTranslation.id() );
@@ -129,7 +128,6 @@ Config::initLanguages()
     // Need to match by some other means than the exact translation Id
     if ( matchedLocaleIndex < 0 )
     {
-
         QLocale defaultLocale = defaultTranslation.locale();
 
         cDebug() << "Trying to match locale" << defaultLocale;
@@ -174,7 +172,7 @@ void
 Config::setCountryCode( const QString& countryCode )
 {
     m_countryCode = countryCode;
-    setLocaleIndex( CalamaresUtils::Locale::availableTranslations()->find( m_countryCode ) );
+    setLocaleIndex( Calamares::Locale::availableTranslations()->find( m_countryCode ) );
 
     emit countryCodeChanged( m_countryCode );
 }
@@ -188,7 +186,7 @@ Config::setLanguageIcon( const QString& languageIcon )
 void
 Config::setLocaleIndex( int index )
 {
-    if ( index == m_localeIndex || index > CalamaresUtils::Locale::availableTranslations()->rowCount( QModelIndex() )
+    if ( index == m_localeIndex || index > Calamares::Locale::availableTranslations()->rowCount( QModelIndex() )
          || index < 0 )
     {
         return;
@@ -201,13 +199,12 @@ Config::setLocaleIndex( int index )
 
     QLocale::setDefault( selectedTranslation.locale() );
     const auto* branding = Calamares::Branding::instance();
-    CalamaresUtils::installTranslator( selectedTranslation.id(),
-                                       branding ? branding->translationsDirectory() : QString() );
+    Calamares::installTranslator( selectedTranslation.id(), branding ? branding->translationsDirectory() : QString() );
     if ( Calamares::JobQueue::instance() && Calamares::JobQueue::instance()->globalStorage() )
     {
-        CalamaresUtils::Locale::insertGS( *Calamares::JobQueue::instance()->globalStorage(),
-                                          QStringLiteral( "LANG" ),
-                                          CalamaresUtils::translatorLocaleName().name );
+        Calamares::Locale::insertGS( *Calamares::JobQueue::instance()->globalStorage(),
+                                     QStringLiteral( "LANG" ),
+                                     Calamares::translatorLocaleName().name );
     }
     emit localeIndexChanged( m_localeIndex );
 }
@@ -247,6 +244,12 @@ Config::setSupportUrl( const QString& url )
     emit supportUrlChanged();
 }
 
+QString
+Config::aboutMessage() const
+{
+    return Calamares::aboutString();
+}
+
 QString
 Config::genericWelcomeMessage() const
 {
@@ -296,11 +299,11 @@ jobOrBrandingSetting( Calamares::Branding::StringEntry e, const QVariantMap& map
         return QString();
     }
     auto v = map.value( key );
-    if ( v.type() == QVariant::Bool )
+    if ( Calamares::typeOf( v ) == Calamares::BoolVariantType )
     {
         return v.toBool() ? ( Calamares::Branding::instance()->string( e ) ) : QString();
     }
-    if ( v.type() == QVariant::String )
+    if ( Calamares::typeOf( v ) == Calamares::StringVariantType )
     {
         return v.toString();
     }
@@ -311,7 +314,7 @@ jobOrBrandingSetting( Calamares::Branding::StringEntry e, const QVariantMap& map
 static inline void
 setLanguageIcon( Config* c, const QVariantMap& configurationMap )
 {
-    QString language = CalamaresUtils::getString( configurationMap, "languageIcon" );
+    QString language = Calamares::getString( configurationMap, "languageIcon" );
     if ( !language.isEmpty() )
     {
         auto icon = Calamares::Branding::instance()->image( language, QSize( 48, 48 ) );
@@ -323,7 +326,7 @@ setLanguageIcon( Config* c, const QVariantMap& configurationMap )
 }
 
 static inline void
-logGeoIPHandler( CalamaresUtils::GeoIP::Handler* handler )
+logGeoIPHandler( Calamares::GeoIP::Handler* handler )
 {
     if ( handler )
     {
@@ -333,7 +336,7 @@ logGeoIPHandler( CalamaresUtils::GeoIP::Handler* handler )
 }
 
 static void
-setCountry( Config* config, const QString& countryCode, CalamaresUtils::GeoIP::Handler* handler )
+setCountry( Config* config, const QString& countryCode, Calamares::GeoIP::Handler* handler )
 {
     if ( countryCode.length() != 2 )
     {
@@ -342,7 +345,7 @@ setCountry( Config* config, const QString& countryCode, CalamaresUtils::GeoIP::H
         return;
     }
 
-    auto c_l = CalamaresUtils::Locale::countryData( countryCode );
+    auto c_l = Calamares::Locale::countryData( countryCode );
     if ( c_l.first == QLocale::Country::AnyCountry )
     {
         cDebug() << "Unusable country code" << countryCode;
@@ -351,7 +354,7 @@ setCountry( Config* config, const QString& countryCode, CalamaresUtils::GeoIP::H
     }
     else
     {
-        int r = CalamaresUtils::Locale::availableTranslations()->find( countryCode );
+        int r = Calamares::Locale::availableTranslations()->find( countryCode );
         if ( r < 0 )
         {
             cDebug() << "Unusable country code" << countryCode << "(no suitable translation)";
@@ -367,15 +370,15 @@ static inline void
 setGeoIP( Config* config, const QVariantMap& configurationMap )
 {
     bool ok = false;
-    QVariantMap geoip = CalamaresUtils::getSubMap( configurationMap, "geoip", ok );
+    QVariantMap geoip = Calamares::getSubMap( configurationMap, "geoip", ok );
     if ( ok )
     {
         using FWString = QFutureWatcher< QString >;
 
-        auto* handler = new CalamaresUtils::GeoIP::Handler( CalamaresUtils::getString( geoip, "style" ),
-                                                            CalamaresUtils::getString( geoip, "url" ),
-                                                            CalamaresUtils::getString( geoip, "selector" ) );
-        if ( handler->type() != CalamaresUtils::GeoIP::Handler::Type::None )
+        auto* handler = new Calamares::GeoIP::Handler( Calamares::getString( geoip, "style" ),
+                                                       Calamares::getString( geoip, "url" ),
+                                                       Calamares::getString( geoip, "selector" ) );
+        if ( handler->type() != Calamares::GeoIP::Handler::Type::None )
         {
             auto* future = new FWString();
             QObject::connect( future,
@@ -412,7 +415,7 @@ Config::setConfigurationMap( const QVariantMap& configurationMap )
     ::setGeoIP( this, configurationMap );
 
     if ( configurationMap.contains( "requirements" )
-         && configurationMap.value( "requirements" ).type() == QVariant::Map )
+         && Calamares::typeOf( configurationMap.value( "requirements" ) ) == Calamares::MapVariantType )
     {
         m_requirementsChecker->setConfigurationMap( configurationMap.value( "requirements" ).toMap() );
     }
